#!/bin/sh

mkdir /usr/share/gnome-sshman
cp libs/gssh-main.glade* /usr/share/gnome-sshman
cp libs/*.py /usr/share/gnome-sshman
cp libs/*png /usr/share/gnome-sshman
cp bin/gnome-sshman /usr/bin
cp -prf i18n/* /usr/share/locale/
cp libs/gnome-sshman.png /usr/share/pixmaps
cp libs/gnome-sshman.desktop /usr/share/applications

echo "Finished..."

